
import com.imsl.stat.*;
import com.imsl.math.PrintMatrix;

public class HoltWintersExponentialSmoothingEx1 {

    public static void main(String args[]) {
        double[] y = {23, 25, 36, 31, 26, 28, 48, 36, 31, 42, 53, 43};
        double confidence = 95.0;
        int nobs = y.length, nseason = 4, nforecasts = nseason;

        // Compute the time series and forecasts
        // using the Multiplicative model.
        HoltWintersExponentialSmoothing hw
                = new HoltWintersExponentialSmoothing(nseason, y);
        hw.setConfidence(confidence);
        hw.setNumberForecasts(nforecasts);
        double[][] ser = hw.compute();
        double[] ysm = hw.getSmoothedSeries();
        double[][] forecasts = hw.getForecasts();

        new PrintMatrix("Input time series").print(y);
        new PrintMatrix("Smoothed Multiplicative series").print(ysm);
        new PrintMatrix("Parameters and internal sequence").print(ser);
        new PrintMatrix("   Multiplicative forecasts\nwith "
                + confidence + "% prediction interval").print(forecasts);
        System.out.println("MSS - Multiplicative "
                + (hw.getSumOfSquares() / (double) (nobs - nseason)));

        // Compute the time series and forecasts
        // using the Additive model.
        hw = new HoltWintersExponentialSmoothing(nseason, y);
        hw.setConfidence(confidence);
        hw.setNumberForecasts(nforecasts);
        hw.setAdditive();
        ser = hw.compute();
        ysm = hw.getSmoothedSeries();
        forecasts = hw.getForecasts();

        new PrintMatrix("\n\nSmoothed Additive series").print(ysm);
        new PrintMatrix("Parameters and internal sequence").print(ser);
        new PrintMatrix("      Additive forecasts\nwith "
                + confidence + "% prediction interval").print(forecasts);
        System.out.println("MSS - Additive "
                + (hw.getSumOfSquares() / (double) (nobs - nseason)));
    }
}
